Class: Aws::MQ::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MQ::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mq/client.rb,
sig/client.rbs
Overview
An API client for MQ. To construct a client, you need to configure a :region and :credentials.
client = Aws::MQ::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateBrokerResponseSuccess, _CreateConfigurationResponseSuccess, _CreateUserResponseSuccess, _DeleteBrokerResponseSuccess, _DeleteConfigurationResponseSuccess, _DeleteUserResponseSuccess, _DescribeBrokerEngineTypesResponseSuccess, _DescribeBrokerInstanceOptionsResponseSuccess, _DescribeBrokerResponseSuccess, _DescribeConfigurationResponseSuccess, _DescribeConfigurationRevisionResponseSuccess, _DescribeSharedResourcesResponseSuccess, _DescribeUserResponseSuccess, _ListBrokersResponseSuccess, _ListConfigurationRevisionsResponseSuccess, _ListConfigurationsResponseSuccess, _ListTagsResponseSuccess, _ListUsersResponseSuccess, _PromoteResponseSuccess, _RebootBrokerResponseSuccess, _UpdateBrokerResponseSuccess, _UpdateConfigurationResponseSuccess, _UpdateUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_broker(params = {}) ⇒ Types::CreateBrokerResponse
Creates a broker.
-
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new configuration for the specified configuration name.
-
#create_tags(params = {}) ⇒ Struct
Add a tag to a resource.
-
#create_user(params = {}) ⇒ Struct
Creates an ActiveMQ user.
-
#delete_broker(params = {}) ⇒ Types::DeleteBrokerResponse
Deletes a broker.
-
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified configuration.
-
#delete_tags(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#delete_user(params = {}) ⇒ Struct
Deletes an ActiveMQ user.
-
#describe_broker(params = {}) ⇒ Types::DescribeBrokerResponse
Returns information about the specified broker.
-
#describe_broker_engine_types(params = {}) ⇒ Types::DescribeBrokerEngineTypesResponse
Describe available engine types and versions.
-
#describe_broker_instance_options(params = {}) ⇒ Types::DescribeBrokerInstanceOptionsResponse
Describe available broker instance options.
-
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns information about the specified configuration.
-
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns the specified configuration revision for the specified configuration.
-
#describe_shared_resources(params = {}) ⇒ Types::DescribeSharedResourcesResponse
Returns the resources shared to a broker.
-
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Returns information about an ActiveMQ user.
-
#list_brokers(params = {}) ⇒ Types::ListBrokersResponse
Returns a list of all brokers.
-
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all revisions for the specified configuration.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all configurations.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Lists tags for a resource.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Returns a list of all ActiveMQ users.
-
#promote(params = {}) ⇒ Types::PromoteResponse
Promotes a data replication replica broker to the primary broker role.
-
#reboot_broker(params = {}) ⇒ Struct
Reboots a broker.
-
#update_broker(params = {}) ⇒ Types::UpdateBrokerResponse
Adds a pending configuration change to a broker.
-
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates the specified configuration.
-
#update_user(params = {}) ⇒ Struct
Updates the information for an ActiveMQ user.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mq/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1822 1823 1824 |
# File 'lib/aws-sdk-mq/client.rb', line 1822 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1825 1826 1827 |
# File 'lib/aws-sdk-mq/client.rb', line 1825 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1795 1796 1797 1798 1799 1800 1801 1802 1803 1804 1805 1806 1807 1808 1809 1810 1811 |
# File 'lib/aws-sdk-mq/client.rb', line 1795 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MQ') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mq' context[:gem_version] = '1.100.0' Seahorse::Client::Request.new(handlers, context) end |
#create_broker(params = {}) ⇒ Types::CreateBrokerResponse
Creates a broker. Note: This API is asynchronous.
To create a broker, you must either use the AmazonMQFullAccess IAM policy or include the following EC2 permissions in your IAM policy.
-
ec2:CreateNetworkInterface
This permission is required to allow Amazon MQ to create an elastic network interface (ENI) on behalf of your account.
-
ec2:CreateNetworkInterfacePermission
This permission is required to attach the ENI to the broker instance.
-
ec2:DeleteNetworkInterface
-
ec2:DeleteNetworkInterfacePermission
-
ec2:DetachNetworkInterface
-
ec2:DescribeInternetGateways
-
ec2:DescribeNetworkInterfaces
-
ec2:DescribeNetworkInterfacePermissions
-
ec2:DescribeRouteTables
-
ec2:DescribeSecurityGroups
-
ec2:DescribeSubnets
-
ec2:DescribeVpcs
For more information, see Create an IAM User and Get Your Amazon Web Services Credentials and Never Modify or Delete the Amazon MQ Elastic Network Interface in the Amazon MQ Developer Guide.
87 |
# File 'sig/client.rbs', line 87
def create_broker: (
|
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new configuration for the specified configuration name. Amazon MQ uses the default configuration (the engine type and version).
144 |
# File 'sig/client.rbs', line 144
def create_configuration: (
|
#create_tags(params = {}) ⇒ Struct
Add a tag to a resource.
154 |
# File 'sig/client.rbs', line 154
def create_tags: (
|
#create_user(params = {}) ⇒ Struct
Creates an ActiveMQ user.
Do not add personally identifiable information (PII) or other confidential or sensitive information in broker usernames. Broker usernames are accessible to other Amazon Web Services services, including CloudWatch Logs. Broker usernames are not intended to be used for private or sensitive data.
164 |
# File 'sig/client.rbs', line 164
def create_user: (
|
#delete_broker(params = {}) ⇒ Types::DeleteBrokerResponse
Deletes a broker. Note: This API is asynchronous.
179 |
# File 'sig/client.rbs', line 179
def delete_broker: (
|
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified configuration.
189 |
# File 'sig/client.rbs', line 189
def delete_configuration: (
|
#delete_tags(params = {}) ⇒ Struct
Removes a tag from a resource.
195 |
# File 'sig/client.rbs', line 195
def delete_tags: (
|
#delete_user(params = {}) ⇒ Struct
Deletes an ActiveMQ user.
205 |
# File 'sig/client.rbs', line 205
def delete_user: (
|
#describe_broker(params = {}) ⇒ Types::DescribeBrokerResponse
Returns information about the specified broker.
250 |
# File 'sig/client.rbs', line 250
def describe_broker: (
|
#describe_broker_engine_types(params = {}) ⇒ Types::DescribeBrokerEngineTypesResponse
Describe available engine types and versions.
262 |
# File 'sig/client.rbs', line 262
def describe_broker_engine_types: (
|
#describe_broker_instance_options(params = {}) ⇒ Types::DescribeBrokerInstanceOptionsResponse
Describe available broker instance options.
276 |
# File 'sig/client.rbs', line 276
def describe_broker_instance_options: (
|
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns information about the specified configuration.
299 |
# File 'sig/client.rbs', line 299
def describe_configuration: (
|
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns the specified configuration revision for the specified configuration.
311 |
# File 'sig/client.rbs', line 311
def describe_configuration_revision: (
|
#describe_shared_resources(params = {}) ⇒ Types::DescribeSharedResourcesResponse
Returns the resources shared to a broker.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
323 |
# File 'sig/client.rbs', line 323
def describe_shared_resources: (
|
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Returns information about an ActiveMQ user.
340 |
# File 'sig/client.rbs', line 340
def describe_user: (
|
#list_brokers(params = {}) ⇒ Types::ListBrokersResponse
Returns a list of all brokers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
352 |
# File 'sig/client.rbs', line 352
def list_brokers: (
|
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all revisions for the specified configuration.
366 |
# File 'sig/client.rbs', line 366
def list_configuration_revisions: (
|
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all configurations.
380 |
# File 'sig/client.rbs', line 380
def list_configurations: (
|
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Lists tags for a resource.
391 |
# File 'sig/client.rbs', line 391
def list_tags: (
|
#list_users(params = {}) ⇒ Types::ListUsersResponse
Returns a list of all ActiveMQ users.
404 |
# File 'sig/client.rbs', line 404
def list_users: (
|
#promote(params = {}) ⇒ Types::PromoteResponse
Promotes a data replication replica broker to the primary broker role.
416 |
# File 'sig/client.rbs', line 416
def promote: (
|
#reboot_broker(params = {}) ⇒ Struct
Reboots a broker. Note: This API is asynchronous.
426 |
# File 'sig/client.rbs', line 426
def reboot_broker: (
|
#update_broker(params = {}) ⇒ Types::UpdateBrokerResponse
Adds a pending configuration change to a broker.
451 |
# File 'sig/client.rbs', line 451
def update_broker: (
|
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates the specified configuration.
488 |
# File 'sig/client.rbs', line 488
def update_configuration: (
|
#update_user(params = {}) ⇒ Struct
Updates the information for an ActiveMQ user.
499 |
# File 'sig/client.rbs', line 499
def update_user: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1815 1816 1817 |
# File 'lib/aws-sdk-mq/client.rb', line 1815 def waiter_names [] end |