Class: Aws::MQ::Types::BrokerSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mq/types.rb

Overview

Returns information about all brokers.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#broker_arnString

The broker's Amazon Resource Name (ARN).



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end

#broker_idString

The unique ID that Amazon MQ generates for the broker.



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end

#broker_nameString

The broker's name. This value is unique in your Amazon Web Services account, 1-50 characters long, and containing only letters, numbers, dashes, and underscores, and must not contain white spaces, brackets, wildcard characters, or special characters.



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end

#broker_stateString

The broker's status.



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end

#createdTime

The time when the broker was created.



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end

#deployment_modeString

The broker's deployment mode.



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end

#engine_typeString

The type of broker engine.



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end

#host_instance_typeString

The broker's instance type.



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/aws-sdk-mq/types.rb', line 244

class BrokerSummary < Struct.new(
  :broker_arn,
  :broker_id,
  :broker_name,
  :broker_state,
  :created,
  :deployment_mode,
  :engine_type,
  :host_instance_type)
  SENSITIVE = []
  include Aws::Structure
end