Class: Aws::MQ::Types::Configuration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mq/types.rb

Overview

Returns information about all configurations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Required. The ARN of the configuration.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#authentication_strategyString

Optional. The authentication strategy associated with the configuration. The default is SIMPLE.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#createdTime

Required. The date and time of the configuration revision.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Required. The description of the configuration.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#engine_typeString

Required. The type of broker engine. Currently, Amazon MQ supports ACTIVEMQ and RABBITMQ.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The broker engine version. Defaults to the latest available version for the specified broker engine type. For a list of supported engine versions, see the ActiveMQ version management and the RabbitMQ version management sections in the Amazon MQ Developer Guide.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#idString

Required. The unique ID that Amazon MQ generates for the configuration.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#latest_revisionTypes::ConfigurationRevision

Required. The latest revision of the configuration.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Required. The name of the configuration. This value can contain only alphanumeric characters, dashes, periods, underscores, and tildes (- . _ ~). This value must be 1-150 characters long.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

The list of all tags associated with this configuration.



314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/aws-sdk-mq/types.rb', line 314

class Configuration < Struct.new(
  :arn,
  :authentication_strategy,
  :created,
  :description,
  :engine_type,
  :engine_version,
  :id,
  :latest_revision,
  :name,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end