Class: Aws::MQ::Types::DescribeSharedResourcesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MQ::Types::DescribeSharedResourcesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mq/types.rb
Overview
Returns the networking resources shared to the broker.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The token that specifies the next page of results Amazon MQ should return.
-
#shared_resources ⇒ Array<Types::SharedResource>
A list of resources shared to the broker.
Instance Attribute Details
#next_token ⇒ String
The token that specifies the next page of results Amazon MQ should return. To request the first page, leave nextToken empty.
1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-mq/types.rb', line 1756 class DescribeSharedResourcesOutput < Struct.new( :next_token, :shared_resources) SENSITIVE = [] include Aws::Structure end |
#shared_resources ⇒ Array<Types::SharedResource>
A list of resources shared to the broker.
1756 1757 1758 1759 1760 1761 |
# File 'lib/aws-sdk-mq/types.rb', line 1756 class DescribeSharedResourcesOutput < Struct.new( :next_token, :shared_resources) SENSITIVE = [] include Aws::Structure end |