Class: Aws::MQ::Types::EncryptionOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::MQ::Types::EncryptionOptions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mq/types.rb
Overview
Encryption options for the broker.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kms_key_id ⇒ String
The customer master key (CMK) to use for the A KMS (KMS).
-
#use_aws_owned_key ⇒ Boolean
Enables the use of an Amazon Web Services owned CMK using KMS (KMS).
Instance Attribute Details
#kms_key_id ⇒ String
The customer master key (CMK) to use for the A KMS (KMS). This key is used to encrypt your data at rest. If not provided, Amazon MQ will use a default CMK to encrypt your data.
1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-mq/types.rb', line 1906 class EncryptionOptions < Struct.new( :kms_key_id, :use_aws_owned_key) SENSITIVE = [] include Aws::Structure end |
#use_aws_owned_key ⇒ Boolean
Enables the use of an Amazon Web Services owned CMK using KMS (KMS). Set to true by default, if no value is provided, for example, for RabbitMQ brokers.
1906 1907 1908 1909 1910 1911 |
# File 'lib/aws-sdk-mq/types.rb', line 1906 class EncryptionOptions < Struct.new( :kms_key_id, :use_aws_owned_key) SENSITIVE = [] include Aws::Structure end |