Class: Aws::MQ::Types::UpdateBrokerInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mq/types.rb

Overview

Updates the broker using the specified properties.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authentication_strategyString

Optional. The authentication strategy used to secure the broker. The default is SIMPLE.

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#auto_minor_version_upgradeBoolean

Enables automatic upgrades to new patch versions for brokers as new versions are released and supported by Amazon MQ. Automatic upgrades occur during the scheduled maintenance window or after a manual broker reboot.

<note markdown=“1”>Must be set to true for ActiveMQ brokers version 5.18 and above and for RabbitMQ brokers version 3.13 and above.

</note>

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#configurationTypes::ConfigurationId

A list of information about the configuration.

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#data_replication_modeString

Defines whether this broker is a part of a data replication pair.

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The broker engine version. For more information, see the [ActiveMQ version management][1] and the [RabbitMQ version management][2] sections in the Amazon MQ Developer Guide.

<note markdown=“1”>When upgrading to ActiveMQ version 5.18 and above or RabbitMQ version 3.13 and above, you must have autoMinorVersionUpgrade set to true for the broker.

</note>

[1]: docs.aws.amazon.com//amazon-mq/latest/developer-guide/activemq-version-management.html [2]: docs.aws.amazon.com//amazon-mq/latest/developer-guide/rabbitmq-version-management.html

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#host_instance_typeString

The broker’s host instance type to upgrade to. For a list of supported instance types, see [Broker instance types][1].

[1]: docs.aws.amazon.com//amazon-mq/latest/developer-guide/broker.html#broker-instance-types

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#ldap_server_metadataTypes::LdapServerMetadataInput

Optional. The metadata of the LDAP server used to authenticate and authorize connections to the broker. Does not apply to RabbitMQ brokers.

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#logsTypes::Logs

Enables Amazon CloudWatch logging for brokers.

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#maintenance_window_start_timeTypes::WeeklyStartTime

The parameters that determine the WeeklyStartTime.

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

The list of security groups (1 minimum, 5 maximum) that authorizes connections to brokers.

Returns:



2685
2686
2687
2688
2689
2690
2691
2692
2693
2694
2695
2696
2697
2698
# File 'lib/aws-sdk-mq/types.rb', line 2685

class UpdateBrokerInput < Struct.new(
  :authentication_strategy,
  :auto_minor_version_upgrade,
  :configuration,
  :data_replication_mode,
  :engine_version,
  :host_instance_type,
  :ldap_server_metadata,
  :logs,
  :maintenance_window_start_time,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end