Class: Aws::MQ::Types::UpdateBrokerOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MQ::Types::UpdateBrokerOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mq/types.rb
Overview
Returns information about the updated broker.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_strategy ⇒ String
Optional.
-
#auto_minor_version_upgrade ⇒ Boolean
Enables automatic upgrades to new patch versions for brokers as new versions are released and supported by Amazon MQ.
-
#broker_id ⇒ String
Required.
-
#configuration ⇒ Types::ConfigurationId
The ID of the updated configuration.
-
#data_replication_metadata ⇒ Types::DataReplicationMetadataOutput
The replication details of the data replication-enabled broker.
-
#data_replication_mode ⇒ String
Describes whether this broker is a part of a data replication pair.
-
#engine_version ⇒ String
The broker engine version to upgrade to.
-
#host_instance_type ⇒ String
The broker's host instance type to upgrade to.
-
#ldap_server_metadata ⇒ Types::LdapServerMetadataOutput
Optional.
-
#logs ⇒ Types::Logs
The list of information about logs to be enabled for the specified broker.
-
#maintenance_window_start_time ⇒ Types::WeeklyStartTime
The parameters that determine the WeeklyStartTime.
-
#pending_data_replication_metadata ⇒ Types::DataReplicationMetadataOutput
The pending replication details of the data replication-enabled broker.
-
#pending_data_replication_mode ⇒ String
Describes whether this broker will be a part of a data replication pair after reboot.
-
#resource_share_arns ⇒ Array<String>
The pending broker's target list of resource shares.
-
#security_groups ⇒ Array<String>
The list of security groups (1 minimum, 5 maximum) that authorizes connections to brokers.
-
#storage_size ⇒ Integer
The broker's storage size in GB.
Instance Attribute Details
#authentication_strategy ⇒ String
Optional. The authentication strategy used to secure the broker. The default is SIMPLE.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
Enables automatic upgrades to new patch versions for brokers as new versions are released and supported by Amazon MQ. Automatic upgrades occur during the scheduled maintenance window or after a manual broker reboot.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#broker_id ⇒ String
Required. The unique ID that Amazon MQ generates for the broker.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::ConfigurationId
The ID of the updated configuration.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#data_replication_metadata ⇒ Types::DataReplicationMetadataOutput
The replication details of the data replication-enabled broker. Only returned if dataReplicationMode is set to CRDR.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#data_replication_mode ⇒ String
Describes whether this broker is a part of a data replication pair.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The broker engine version to upgrade to. For more information, see the ActiveMQ version management and the RabbitMQ version management sections in the Amazon MQ Developer Guide.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#host_instance_type ⇒ String
The broker's host instance type to upgrade to. For a list of supported instance types, see Broker instance types.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#ldap_server_metadata ⇒ Types::LdapServerMetadataOutput
Optional. The metadata of the LDAP server used to authenticate and authorize connections to the broker. Does not apply to RabbitMQ brokers.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#logs ⇒ Types::Logs
The list of information about logs to be enabled for the specified broker.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#maintenance_window_start_time ⇒ Types::WeeklyStartTime
The parameters that determine the WeeklyStartTime.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#pending_data_replication_metadata ⇒ Types::DataReplicationMetadataOutput
The pending replication details of the data replication-enabled broker. Only returned if pendingDataReplicationMode is set to CRDR.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#pending_data_replication_mode ⇒ String
Describes whether this broker will be a part of a data replication pair after reboot.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#resource_share_arns ⇒ Array<String>
The pending broker's target list of resource shares.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The list of security groups (1 minimum, 5 maximum) that authorizes connections to brokers.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#storage_size ⇒ Integer
The broker's storage size in GB.
2999 3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 3012 3013 3014 3015 3016 3017 3018 |
# File 'lib/aws-sdk-mq/types.rb', line 2999 class UpdateBrokerOutput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :broker_id, :configuration, :data_replication_metadata, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :pending_data_replication_metadata, :pending_data_replication_mode, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |