Class: Aws::MQ::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MQ::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-mq/client.rb,
sig/client.rbs
Overview
An API client for MQ. To construct a client, you need to configure a :region and :credentials.
client = Aws::MQ::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateBrokerResponseSuccess, _CreateConfigurationResponseSuccess, _CreateUserResponseSuccess, _DeleteBrokerResponseSuccess, _DeleteConfigurationResponseSuccess, _DeleteUserResponseSuccess, _DescribeBrokerEngineTypesResponseSuccess, _DescribeBrokerInstanceOptionsResponseSuccess, _DescribeBrokerResponseSuccess, _DescribeConfigurationResponseSuccess, _DescribeConfigurationRevisionResponseSuccess, _DescribeSharedResourcesResponseSuccess, _DescribeUserResponseSuccess, _ListBrokersResponseSuccess, _ListConfigurationRevisionsResponseSuccess, _ListConfigurationsResponseSuccess, _ListTagsResponseSuccess, _ListUsersResponseSuccess, _PromoteResponseSuccess, _RebootBrokerResponseSuccess, _UpdateBrokerResponseSuccess, _UpdateConfigurationResponseSuccess, _UpdateUserResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_broker(params = {}) ⇒ Types::CreateBrokerResponse
Creates a broker.
-
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new configuration for the specified configuration name.
-
#create_tags(params = {}) ⇒ Struct
Add a tag to a resource.
-
#create_user(params = {}) ⇒ Struct
Creates an ActiveMQ user.
-
#delete_broker(params = {}) ⇒ Types::DeleteBrokerResponse
Deletes a broker.
-
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified configuration.
-
#delete_tags(params = {}) ⇒ Struct
Removes a tag from a resource.
-
#delete_user(params = {}) ⇒ Struct
Deletes an ActiveMQ user.
-
#describe_broker(params = {}) ⇒ Types::DescribeBrokerResponse
Returns information about the specified broker.
-
#describe_broker_engine_types(params = {}) ⇒ Types::DescribeBrokerEngineTypesResponse
Describe available engine types and versions.
-
#describe_broker_instance_options(params = {}) ⇒ Types::DescribeBrokerInstanceOptionsResponse
Describe available broker instance options.
-
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns information about the specified configuration.
-
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns the specified configuration revision for the specified configuration.
-
#describe_shared_resources(params = {}) ⇒ Types::DescribeSharedResourcesResponse
Returns the resources shared to a broker.
-
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Returns information about an ActiveMQ user.
-
#list_brokers(params = {}) ⇒ Types::ListBrokersResponse
Returns a list of all brokers.
-
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all revisions for the specified configuration.
-
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all configurations.
-
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Lists tags for a resource.
-
#list_users(params = {}) ⇒ Types::ListUsersResponse
Returns a list of all ActiveMQ users.
-
#promote(params = {}) ⇒ Types::PromoteResponse
Promotes a data replication replica broker to the primary broker role.
-
#reboot_broker(params = {}) ⇒ Struct
Reboots a broker.
-
#update_broker(params = {}) ⇒ Types::UpdateBrokerResponse
Adds a pending configuration change to a broker.
-
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates the specified configuration.
-
#update_user(params = {}) ⇒ Struct
Updates the information for an ActiveMQ user.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-mq/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1808 1809 1810 |
# File 'lib/aws-sdk-mq/client.rb', line 1808 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1811 1812 1813 |
# File 'lib/aws-sdk-mq/client.rb', line 1811 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1781 1782 1783 1784 1785 1786 1787 1788 1789 1790 1791 1792 1793 1794 1795 1796 1797 |
# File 'lib/aws-sdk-mq/client.rb', line 1781 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MQ') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-mq' context[:gem_version] = '1.99.0' Seahorse::Client::Request.new(handlers, context) end |
#create_broker(params = {}) ⇒ Types::CreateBrokerResponse
Creates a broker. Note: This API is asynchronous.
To create a broker, you must either use the AmazonMQFullAccess IAM policy or include the following EC2 permissions in your IAM policy.
-
ec2:CreateNetworkInterface
This permission is required to allow Amazon MQ to create an elastic network interface (ENI) on behalf of your account.
-
ec2:CreateNetworkInterfacePermission
This permission is required to attach the ENI to the broker instance.
-
ec2:DeleteNetworkInterface
-
ec2:DeleteNetworkInterfacePermission
-
ec2:DetachNetworkInterface
-
ec2:DescribeInternetGateways
-
ec2:DescribeNetworkInterfaces
-
ec2:DescribeNetworkInterfacePermissions
-
ec2:DescribeRouteTables
-
ec2:DescribeSecurityGroups
-
ec2:DescribeSubnets
-
ec2:DescribeVpcs
For more information, see Create an IAM User and Get Your Amazon Web Services Credentials and Never Modify or Delete the Amazon MQ Elastic Network Interface in the Amazon MQ Developer Guide.
87 |
# File 'sig/client.rbs', line 87
def create_broker: (
|
#create_configuration(params = {}) ⇒ Types::CreateConfigurationResponse
Creates a new configuration for the specified configuration name. Amazon MQ uses the default configuration (the engine type and version).
143 |
# File 'sig/client.rbs', line 143
def create_configuration: (
|
#create_tags(params = {}) ⇒ Struct
Add a tag to a resource.
153 |
# File 'sig/client.rbs', line 153
def create_tags: (
|
#create_user(params = {}) ⇒ Struct
Creates an ActiveMQ user.
Do not add personally identifiable information (PII) or other confidential or sensitive information in broker usernames. Broker usernames are accessible to other Amazon Web Services services, including CloudWatch Logs. Broker usernames are not intended to be used for private or sensitive data.
163 |
# File 'sig/client.rbs', line 163
def create_user: (
|
#delete_broker(params = {}) ⇒ Types::DeleteBrokerResponse
Deletes a broker. Note: This API is asynchronous.
178 |
# File 'sig/client.rbs', line 178
def delete_broker: (
|
#delete_configuration(params = {}) ⇒ Types::DeleteConfigurationResponse
Deletes the specified configuration.
188 |
# File 'sig/client.rbs', line 188
def delete_configuration: (
|
#delete_tags(params = {}) ⇒ Struct
Removes a tag from a resource.
194 |
# File 'sig/client.rbs', line 194
def delete_tags: (
|
#delete_user(params = {}) ⇒ Struct
Deletes an ActiveMQ user.
204 |
# File 'sig/client.rbs', line 204
def delete_user: (
|
#describe_broker(params = {}) ⇒ Types::DescribeBrokerResponse
Returns information about the specified broker.
247 |
# File 'sig/client.rbs', line 247
def describe_broker: (
|
#describe_broker_engine_types(params = {}) ⇒ Types::DescribeBrokerEngineTypesResponse
Describe available engine types and versions.
259 |
# File 'sig/client.rbs', line 259
def describe_broker_engine_types: (
|
#describe_broker_instance_options(params = {}) ⇒ Types::DescribeBrokerInstanceOptionsResponse
Describe available broker instance options.
273 |
# File 'sig/client.rbs', line 273
def describe_broker_instance_options: (
|
#describe_configuration(params = {}) ⇒ Types::DescribeConfigurationResponse
Returns information about the specified configuration.
296 |
# File 'sig/client.rbs', line 296
def describe_configuration: (
|
#describe_configuration_revision(params = {}) ⇒ Types::DescribeConfigurationRevisionResponse
Returns the specified configuration revision for the specified configuration.
308 |
# File 'sig/client.rbs', line 308
def describe_configuration_revision: (
|
#describe_shared_resources(params = {}) ⇒ Types::DescribeSharedResourcesResponse
Returns the resources shared to a broker.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
320 |
# File 'sig/client.rbs', line 320
def describe_shared_resources: (
|
#describe_user(params = {}) ⇒ Types::DescribeUserResponse
Returns information about an ActiveMQ user.
337 |
# File 'sig/client.rbs', line 337
def describe_user: (
|
#list_brokers(params = {}) ⇒ Types::ListBrokersResponse
Returns a list of all brokers.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
349 |
# File 'sig/client.rbs', line 349
def list_brokers: (
|
#list_configuration_revisions(params = {}) ⇒ Types::ListConfigurationRevisionsResponse
Returns a list of all revisions for the specified configuration.
363 |
# File 'sig/client.rbs', line 363
def list_configuration_revisions: (
|
#list_configurations(params = {}) ⇒ Types::ListConfigurationsResponse
Returns a list of all configurations.
377 |
# File 'sig/client.rbs', line 377
def list_configurations: (
|
#list_tags(params = {}) ⇒ Types::ListTagsResponse
Lists tags for a resource.
388 |
# File 'sig/client.rbs', line 388
def list_tags: (
|
#list_users(params = {}) ⇒ Types::ListUsersResponse
Returns a list of all ActiveMQ users.
401 |
# File 'sig/client.rbs', line 401
def list_users: (
|
#promote(params = {}) ⇒ Types::PromoteResponse
Promotes a data replication replica broker to the primary broker role.
413 |
# File 'sig/client.rbs', line 413
def promote: (
|
#reboot_broker(params = {}) ⇒ Struct
Reboots a broker. Note: This API is asynchronous.
423 |
# File 'sig/client.rbs', line 423
def reboot_broker: (
|
#update_broker(params = {}) ⇒ Types::UpdateBrokerResponse
Adds a pending configuration change to a broker.
447 |
# File 'sig/client.rbs', line 447
def update_broker: (
|
#update_configuration(params = {}) ⇒ Types::UpdateConfigurationResponse
Updates the specified configuration.
483 |
# File 'sig/client.rbs', line 483
def update_configuration: (
|
#update_user(params = {}) ⇒ Struct
Updates the information for an ActiveMQ user.
494 |
# File 'sig/client.rbs', line 494
def update_user: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1801 1802 1803 |
# File 'lib/aws-sdk-mq/client.rb', line 1801 def waiter_names [] end |