Class: Aws::MQ::Types::UpdateBrokerInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::MQ::Types::UpdateBrokerInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-mq/types.rb
Overview
Updates the broker using the specified properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authentication_strategy ⇒ String
Optional.
-
#auto_minor_version_upgrade ⇒ Boolean
Enables automatic upgrades to new patch versions for brokers as new versions are released and supported by Amazon MQ.
-
#configuration ⇒ Types::ConfigurationId
A list of information about the configuration.
-
#data_replication_mode ⇒ String
Defines whether this broker is a part of a data replication pair.
-
#engine_version ⇒ String
The broker engine version.
-
#host_instance_type ⇒ String
The broker's host instance type to upgrade to.
-
#ldap_server_metadata ⇒ Types::LdapServerMetadataInput
Optional.
-
#logs ⇒ Types::Logs
Enables Amazon CloudWatch logging for brokers.
-
#maintenance_window_start_time ⇒ Types::WeeklyStartTime
The parameters that determine the WeeklyStartTime.
-
#resource_share_arns ⇒ Array<String>
The list of resource shares to update on the broker.
-
#security_groups ⇒ Array<String>
The list of security groups (1 minimum, 5 maximum) that authorizes connections to brokers.
-
#storage_size ⇒ Integer
The broker's storage size in GB.
Instance Attribute Details
#authentication_strategy ⇒ String
Optional. The authentication strategy used to secure the broker. The default is SIMPLE.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#auto_minor_version_upgrade ⇒ Boolean
Enables automatic upgrades to new patch versions for brokers as new versions are released and supported by Amazon MQ. Automatic upgrades occur during the scheduled maintenance window or after a manual broker reboot.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#configuration ⇒ Types::ConfigurationId
A list of information about the configuration.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#data_replication_mode ⇒ String
Defines whether this broker is a part of a data replication pair.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The broker engine version. For more information, see the ActiveMQ version management and the RabbitMQ version management sections in the Amazon MQ Developer Guide.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#host_instance_type ⇒ String
The broker's host instance type to upgrade to. For a list of supported instance types, see Broker instance types.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#ldap_server_metadata ⇒ Types::LdapServerMetadataInput
Optional. The metadata of the LDAP server used to authenticate and authorize connections to the broker. Does not apply to RabbitMQ brokers.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#logs ⇒ Types::Logs
Enables Amazon CloudWatch logging for brokers.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#maintenance_window_start_time ⇒ Types::WeeklyStartTime
The parameters that determine the WeeklyStartTime.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#resource_share_arns ⇒ Array<String>
The list of resource shares to update on the broker.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The list of security groups (1 minimum, 5 maximum) that authorizes connections to brokers.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |
#storage_size ⇒ Integer
The broker's storage size in GB.
2891 2892 2893 2894 2895 2896 2897 2898 2899 2900 2901 2902 2903 2904 2905 2906 |
# File 'lib/aws-sdk-mq/types.rb', line 2891 class UpdateBrokerInput < Struct.new( :authentication_strategy, :auto_minor_version_upgrade, :configuration, :data_replication_mode, :engine_version, :host_instance_type, :ldap_server_metadata, :logs, :maintenance_window_start_time, :resource_share_arns, :security_groups, :storage_size) SENSITIVE = [] include Aws::Structure end |